@@ -1,21 +1,19 @@
-from __future__ import absolute_import, division, print_function
 from .due import due, Doi
-from .layout import BIDSLayout
+from .layout import BIDSLayout, BIDSLayoutIndexer
 
 # For backwards compatibility
 from bids_validator import BIDSValidator
 
-
 __all__ = [
     "analysis",
     "BIDSLayout",
+    "BIDSLayoutIndexer",
     "BIDSValidator",
     "config",
     "layout",
     "reports",
     "utils",
     "variables"
-
 ]
 
 due.cite(Doi("10.1038/sdata.2016.44"),
@@ -26,5 +24,6 @@ due.cite(Doi("10.1038/sdata.2016.44"),
 del due, Doi
 
 from ._version import get_versions
+
 __version__ = get_versions()['version']
 del get_versions
